@@ -45,18 +45,18 @@ do_view_action() {
             cat "${MC_EXT_FILENAME}"
             ;;
         *)
-            { zsoelim "${MC_EXT_FILENAME}" 2>/dev/null || cat "${MC_EXT_FILENAME}"; } | nroff -c -Tlatin1 -mandoc
+            MANROFFOPT=-c MAN_KEEP_FORMATTING=1 man -P cat -l "${MC_EXT_FILENAME}"
             ;;
         esac
         ;;
     pod)
-        pod2man "${MC_EXT_FILENAME}" | nroff -c -Tlatin1 -mandoc
+        pod2man "${MC_EXT_FILENAME}" | nroff  -man
         ;;
     nroff.me)
-        nroff -c -Tlatin1 -me "${MC_EXT_FILENAME}"
+        nroff  -me "${MC_EXT_FILENAME}"
         ;;
     nroff.ms)
-        nroff -c -Tlatin1 -ms "${MC_EXT_FILENAME}"
+        nroff  -ms "${MC_EXT_FILENAME}"
         ;;
     man.gz|man.bz|man.bz2|man.lzma|man.xz)
         case "${MC_EXT_FILENAME}" in
@@ -64,7 +64,9 @@ do_view_action() {
             ${unpacker} "${MC_EXT_FILENAME}"
             ;;
         *)
-            ${unpacker} "${MC_EXT_FILENAME}" | nroff -c -Tlatin1 -mandoc
+            # "man" takes care of uncompressing.
+            # This way the stdin is left intact so the correct width is used.
+            MANROFFOPT=-c MAN_KEEP_FORMATTING=1 man -P cat -l "${MC_EXT_FILENAME}"
             ;;
         esac
         ;;
@@ -90,18 +92,18 @@ do_open_action() {
             ;;
         *)
             { zsoelim "${MC_EXT_FILENAME}" 2>/dev/null || cat "${MC_EXT_FILENAME}"; } | \
-                nroff -c -Tlatin1 -mandoc
+                nroff  -man
             ;;
         esac | ${pager}
         ;;
     pod)
-        pod2man "${MC_EXT_FILENAME}" | nroff -c -Tlatin1 -mandoc | ${pager}
+        pod2man "${MC_EXT_FILENAME}" | nroff  -man | ${pager}
         ;;
     nroff.me)
-        nroff -c -Tlatin1 -me "${MC_EXT_FILENAME}" | ${pager}
+        nroff  -me "${MC_EXT_FILENAME}" | ${pager}
         ;;
     nroff.ms)
-        nroff -c -Tlatin1 -ms "${MC_EXT_FILENAME}" | ${pager}
+        nroff  -ms "${MC_EXT_FILENAME}" | ${pager}
         ;;
     man.gz|man.bz|man.bz2|man.lzma|man.xz)
         case "${MC_EXT_FILENAME}" in
@@ -109,7 +111,7 @@ do_open_action() {
             ${unpacker} "${MC_EXT_FILENAME}"
             ;;
         *)
-            ${unpacker} "${MC_EXT_FILENAME}" | nroff -c -Tlatin1 -mandoc
+            ${unpacker} "${MC_EXT_FILENAME}" | nroff  -man
             ;;
         esac | ${pager}
         ;;
